﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Collections.ObjectModel;
using System.Web;



using ThinkGeo.MapSuite.Core;       // -----------MapSuiteCore
using ThinkGeo.MapSuite.WebEdition;  // -----------WebEdition

namespace CSSamples
{


  public class MyMarkerStyle : MarkerStyle
  {

    // Summary:
    //     Initialize a new instance of the ValueMarkerStyle class.
    public MyMarkerStyle() { }


    


    // Summary:
    //     Returns a collection of markers with a style applied based on the features
    //     that are passed in.
    //
    // Parameters:
    //   features:
    //     A collection of features used to create the markers.
    //
    // Returns:
    //     A collection of markers with a style applied based on the features that are
    //     passed in.
    public override Collection<Marker> GetMarkers(IEnumerable<Feature> features)
    {
      Collection<Marker> collectionMarkers = new Collection<Marker>();

      String path = "./theme/default/icons/Small/";

      foreach (Feature feature in features)
      {
        //Feature feature = features[idx];
        Marker marker = new Marker();
        marker.Position = feature.GetShape() as PointShape;

        if (feature.Id == "San Diego")
        {
          //marker.WebImage = new WebImage("../../theme/default/img/green.png", 21, 25);
          marker.WebImage = new WebImage("../../theme/default/img/green.png");
          //marker.WebImage = new WebImage(path + feature.ColumnValues["Style"] + ".png");
        }
        else
        {
          //marker.WebImage = new WebImage("../../theme/default/img/blue.png", 21, 25);
          marker.WebImage = new WebImage("../../theme/default/img/blue.png");
        }

        marker.WebImage.ImageHeight = 40;
        marker.WebImage.ImageWidth = 40;

        marker.WebImage.Text = "5";


        marker.WebImage.FontColor = GeoColor.StandardColors.Black;

        marker.WebImage.FontStyle = new GeoFont("Arial Black", 10, DrawingFontStyles.Bold);
        marker.WebImage.TextOffsetX = 8F;
        marker.WebImage.TextOffsetY = 8F;

    
        
        if (null != marker)
        {
          collectionMarkers.Add(marker);
        }
      } // end foreach    

      // Initialize tag list
      List<int> tagList = new List<int>();

      for (int idx = 0; idx < collectionMarkers.Count; idx++)
      {
        tagList.Add(0);
      }
      // Setting offset for overlapping markers

      for (int idx = 0; idx < collectionMarkers.Count; idx++)
      {
        Marker marker = collectionMarkers[idx];

        PointShape ptShapeMarker = marker.Position;

        Collection<Marker> clusterMarkers = new Collection<Marker>();

        for (int jnx = idx + 1; jnx < collectionMarkers.Count; jnx++)
        {
          if (tagList[jnx] == 0)
          {
            Marker candMarker = collectionMarkers[jnx];

            if (ptShapeMarker.Equal2D(candMarker.Position))
            {
              tagList[jnx] = 1;
              clusterMarkers.Add(candMarker);
            }
          }
        }// index = jnx

        double deltaDegree = 0.0;
        float radOffSet = 30.0f;
        if (clusterMarkers.Count >= 1)
        {
          deltaDegree = 360.0 / clusterMarkers.Count;
        }

        for (int knx = 0; knx < clusterMarkers.Count; knx++)
        {
          Marker clusterMarker = clusterMarkers[knx];
          double curDegree = deltaDegree * (knx);          

          float x = (float)Math.Cos(curDegree / 180 * Math.PI) * radOffSet;
          float y = (float)Math.Sin(curDegree / 180 * Math.PI) * radOffSet;

          clusterMarker.WebImage.ImageOffsetX = -x;
          clusterMarker.WebImage.ImageOffsetY = -y;

        }

      } // index = idx

      return collectionMarkers;
    }

  }
}